Struct luk_chain::BlockChain[][src]

pub struct BlockChain<T> {
    pub chain: Vec<Block<T>>,
    pub users: HashMap<u128, RsaPublicKey>,
    pub created_at: Duration,
    // some fields omitted
}
Struct to define local copy of blockchain

Fields

chain: Vec<Block<T>>

Contains all Block instances in chain

users: HashMap<u128, RsaPublicKey>

All known participants in network

created_at: Duration

Time since Epoch that BlockChain was created

Implementations

Creates a new [Blockchain] instance

Gets the hash of the most recent Block in the chain

Adds a new Block to the [Blockchain]

[id] is the ID of the user who is in charge of the local instance of the BlockChain

Goes through the [Blockchain] and validates it

Goes through the BlockChain and checks if Event is already in BlockChain

Adds a new user to BlockChain

Length of underlying BlockChain

Calculates the percentage similarity with compared BlockChain

Check if Block is in chain

Sets the location to write the BlockChain to

Returns the location of the BlockChain in the filesystem

Writes the current state of the BlockChain to its specified file